@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@imendio.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Author: Mikael Hallendal <micke@codefactory.se>
+ * Author: Mikael Hallendal <micke@imendio.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,7 +37,13 @@ yelp_section_new (YelpSectionType  type,
 	section = g_new0 (YelpSection, 1);
 
 	section->type      = type;
-	section->name      = g_strdup (name);
+
+	if (name) {
+		section->name = g_strdup (name);
+	} else {
+		section->name = g_strdup ("");
+	}
+	
 	if (uri) {
 		section->uri = yelp_uri_ref (uri);
 	} else {
